@@ -2,21 +2,19 @@ import os
 
 name = "pysnowball"
 
-__version__ = '0.0.2'
 __author__ = 'Yang Yu'
 
-"""
-for finance data
-"""
+
 from pysnowball.finance import (cash_flow, indicator, balance, income, business)
 
 from pysnowball.report import (report, earningforecast)
 
-from pysnowball.capital import(margin, blocktrans, assort, flow, history)
+from pysnowball.capital import(
+    margin, blocktrans, capital_assort, capital_flow, capital_history)
 
 from pysnowball.realtime import(quotec, pankou)
 
-from pysnowball.f10 import(skholderchg, skholder,
+from pysnowball.f10 import(skholderchg, skholder, main_indicator,
                            industry, holders, bonus, org_holding_change, 
                            industry_compare, business_analysis, shareschg, top_holders)
 
